@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-12 20:04:54
-:LastEditTime: 2021-04-15 15:26:08
+:LastEditTime: 2021-08-04 17:29:36
 :LastEditors: HuangJingCan
 :description: 用户相关
 """
@@ -55,7 +55,7 @@ class UserListHandler(SevenBaseHandler):
             condition += " AND user_nick=%s"
             params.append(user_nick)
 
-        page_list, total = UserInfoModel(context=self).get_dict_page_list("id,act_id,open_id,user_nick,pay_price,user_state,surplus_integral", page_index, page_size, condition, order_by="id desc", params=params)
+        page_list, total = UserInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)
 
         if page_list:
             where_machine_value = SevenHelper.get_condition_by_id_list("open_id", [i["open_id"] for i in page_list])
