@@ -2,12 +2,12 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-06-23 10:35:52
-@LastEditors: WangQiang
+:LastEditTime: 2021-07-27 15:47:12
+:LastEditors: HuangJingCan
 :Description: 潮玩盲盒基础路由
 """
 # 框架引用
-from seven_cloudapp.handlers.monitor import *
+from seven_framework.web_tornado.monitor import MonitorHandler
 from seven_cloudapp.handlers.core import *
 from seven_cloudapp.handlers.server import *
 from seven_cloudapp.handlers.client import *
